current library

A simple yet powerful state management library for Flutter.

Classes

BusyStatusChanged
Event that is added to the state stream when the busy status of the view model changes.
Current<T extends CurrentViewModel>
Used to provide shared state and functions across specific scopes of your application, or the entire application itself.
CurrentApp<T extends CurrentViewModel>
This widget is not intended to be created manually and is used by the Current widget.
CurrentBoolProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object
CurrentCloneable<T>
CurrentDateTimeProperty
An CurrentProperty with similar characteristics as a an ordinary dart DateTime object
CurrentDateTimeTextController
A CurrentTextController that can only be bound to a CurrentProperty of type DateTime.
CurrentDoubleProperty
An CurrentProperty with similar characteristics of dart double objects
CurrentFieldValidation<T>
Tracks validation metadata for a single CurrentProperty.
CurrentGenericTextController<T extends Object>
A CurrentTextController that is bindable to a CurrentProperty of type T.
CurrentIntProperty
An CurrentProperty with similar characteristics of dart int objects
CurrentIntTextController
A CurrentTextController that can only be bound to a CurrentProperty of type int.
CurrentListProperty<T>
An CurrentProperty with similar characteristics as a dart List<T>
CurrentMapProperty<K, V>
An CurrentProperty with similar characteristics as a dart Map<K, V>
CurrentNullableBoolProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object.
CurrentNullableDateTimeProperty
An CurrentProperty with similar characteristics as a an ordinary dart bool object.
CurrentNullableDateTimeTextController
A CurrentTextController that can only be bound to a CurrentProperty of type DateTime?.
CurrentNullableDoubleProperty
An CurrentProperty with similar characteristics of dart double objects
CurrentNullableIntProperty
An CurrentProperty with similar characteristics of dart int objects
CurrentNullableIntTextController
A CurrentTextController that can only be bound to a CurrentProperty of type int?.
CurrentNullableStringProperty
An CurrentProperty with similar characteristics as a dart String object
CurrentNullableStringTextController
A CurrentTextController that can only be bound to a CurrentProperty of type String?.
CurrentProperty<T>
Contains any object that will notify any listeners when its value is changed.
CurrentState<T extends CurrentWidget<CurrentViewModel>, E extends CurrentViewModel>
Base class for your CurrentWidgets accompanying State class.
CurrentStateChanged<T>
The event that is added to the State stream.
CurrentStateViewModel
A ViewModel is an abstraction of the view it is bound to and represents the current state of the data in your model.
CurrentStringProperty
An CurrentProperty with similar characteristics as a dart String object
CurrentStringTextController
A CurrentTextController that can only be bound to a CurrentProperty of type String.
CurrentTextController<T>
A TextEditingController that keeps a CurrentProperty and a text field in sync.
CurrentTextControllerValidationIssues
Supplies controller-generated validation issues for CurrentTextController.
CurrentTextField<T>
A convenience TextField wired to a CurrentTextController.
CurrentTextFormField<T>
A convenience TextFormField wired to a CurrentTextController.
CurrentValidationChanged
Event sent when the validation metadata for a field changes.
CurrentValidationGroup
Aggregates multiple CurrentFieldValidation instances.
CurrentValidationIssue
Describes a validation failure without tying it to a specific locale.
CurrentValidationState
Represents the current validation metadata for a field.
CurrentValue<T>
Base class for CurrentProperty
CurrentViewModel
A ViewModel is an abstraction of the view it is bound to and represents the current state of the data in your model.
CurrentViewModelBinding
Contract for helper objects that need to attach themselves to a CurrentStateViewModel after all CurrentProperty values have been initialized.
CurrentWidget<T extends CurrentViewModel>
Base class for any widget that needs to be updated when the state of your widget changes.
ErrorEvent<T>
The event that is added to the Error stream.

Mixins

CurrentTextControllersLifecycleMixin<TWidget extends CurrentWidget<CurrentViewModel>, TViewModel extends CurrentViewModel>
A mixin for managing the lifecycle of CurrentTextControllers in a CurrentState.

Functions

createNullProperty<T>({String? propertyName}) CurrentProperty<T?>
Short hand helper function for initializing an CurrentProperty with a null value.
createProperty<T>(T value, {String? propertyName}) CurrentProperty<T>
Short hand helper function for initializing an CurrentProperty.

Exceptions / Errors

CurrentException
Base class for any Current specific exception
CurrentIntPropertyInvalidArithmaticException
Thrown when a CurrentIntProperty arithmetic function cannot convert its numeric result into the explicitly requested generic type.
CurrentPropertyException
CurrentPropertyNullValueException
Thrown when an not-null-safe action is performed on a Nullable Current Property, and the underlying value was null.
CurrentViewModelAlreadyAssignedException
Thrown when a CurrentViewModel is assigned to a CurrentState, but that CurrentViewModel is already assigned to a different CurrentState.
PropertyNotAssignedToCurrentViewModelException
Thrown when an CurrentProperty value is changed and attempts to update the UI, but has not been added to the currentProps property of the associated CurrentViewModel