validationSourceHashCode property
Unique identifier for this validation instance.
This can be used to distinguish between multiple validators targeting the same property when listening to CurrentValidationChanged events.
Implementation
final int validationSourceHashCode = identityHashCode(Object());