CurrentTextFormField<T> class
A convenience TextFormField wired to a CurrentTextController.
This keeps Flutter's native form behavior and AutovalidateMode behavior while delegating property synchronization and validation to Current.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CurrentTextFormField
Constructors
-
CurrentTextFormField({Key? key, required CurrentTextController<
T> controller, CurrentValidationIssueTextResolver? validationTextResolver, AutovalidateMode? autovalidateMode, InputDecoration decoration = const InputDecoration(), FocusNode? focusNode, TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization textCapitalization = TextCapitalization.none, TextAlign textAlign = TextAlign.start, TextStyle? style, bool readOnly = false, bool? enabled, bool autofocus = false, bool obscureText = false, int? minLines, int? maxLines = 1, int? maxLength, bool expands = false, List<TextInputFormatter> ? inputFormatters, ValueChanged<String> ? onChanged, ValueChanged<String> ? onFieldSubmitted, GestureTapCallback? onTap}) -
const
Properties
- autofocus → bool
-
final
- autovalidateMode → AutovalidateMode?
-
final
-
controller
→ CurrentTextController<
T> -
final
- decoration → InputDecoration
-
final
- enabled → bool?
-
final
- expands → bool
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- obscureText → bool
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
-
onFieldSubmitted
→ ValueChanged<
String> ? -
final
- onTap → GestureTapCallback?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
final
- textAlign → TextAlign
-
final
- textCapitalization → TextCapitalization
-
final
- textInputAction → TextInputAction?
-
final
- validationTextResolver → CurrentValidationIssueTextResolver?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited