CurrentGenericTextController<T extends Object> class
final
A CurrentTextController that is bindable to a CurrentProperty of type T.
Use CurrentTextController.of to create an instance of this controller.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
TextEditingValue> - TextEditingController
- CurrentTextController<
T> - CurrentGenericTextController
Properties
- asString → String? Function(T? propertyValue)?
-
no setterinherited
- defaultValue → T?
-
no setterinherited
- fromString → T Function(String text)?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isSynchronizingText → bool
-
Whether the controller is currently applying a synchronized text update
from the bound property.
no setterinherited
-
property
→ CurrentProperty<
T?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection ↔ TextSelection
-
The currently selected range within text.
getter/setter pairinherited
- text ↔ String
-
The current string the user is editing.
getter/setter pairinherited
- validation → CurrentFieldValidation?
-
no setterinherited
- validationIssues → CurrentTextControllerValidationIssues?
-
no setterinherited
- value ↔ TextEditingValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
bind(
{required CurrentProperty< T> property, required CurrentTextControllersLifecycleMixin<CurrentWidget< lifecycleProvider, required T fromString(String text), String? asString(T propertyValue)?, T? defaultValue, CurrentFieldValidation? validation, CurrentTextControllerValidationBuilder<CurrentViewModel> , CurrentViewModel>T> ? validationBuilder, CurrentTextControllerValidationIssues? validationIssues}) → void -
buildTextSpan(
{required BuildContext context, TextStyle? style, required bool withComposing}) → TextSpan -
Builds TextSpan from current editing value.
inherited
-
clear(
) → void -
Set the value to empty.
inherited
-
clearComposing(
) → void -
Set the composing region to an empty range.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
formValidator(
{BuildContext? context, CurrentValidationIssueTextResolver? resolver, bool markTouched = true}) → FormFieldValidator< String> ? -
Creates a stock Flutter FormField.validator callback for this
controller.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
previewValidationIssue(
) → CurrentValidationIssue? -
Computes the current validation issue for the controller text without
mutating validation state.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
synchronizeValidation(
{bool markTouched = true, bool resetTextOnRequiredFailure = true}) → void -
Synchronizes validation metadata with the controller's current text.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visibleErrorText(
{BuildContext? context, CurrentValidationIssueTextResolver? resolver}) → String? -
Resolves the currently visible validation error for text-field style
widgets that still use
InputDecoration.errorTextdirectly.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited