CurrentViewModelBinding class abstract
Contract for helper objects that need to attach themselves to a CurrentStateViewModel after all CurrentProperty values have been initialized.
Generic helper implementations can be exposed from CurrentStateViewModel.currentBindings.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachToViewModel(
) → void - Attaches this helper to its owning CurrentStateViewModel.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited